@@ -10,6 +10,7 @@
 #ifndef CDCAT_CDCAT
 #define CDCAT_CDCAT
 
+#include <qtranslator.h>
 #include "config.h"
 
 #define IS_RELEASE
@@ -17,12 +18,12 @@
 
 // CdCat version text:
 
-#define VERSION  "UNICODE 1.2"
+#define VERSION  "UNICODE 2.2"
 
 
 // Datafile version:
 // The known versions listed in guibase.cpp - checkversion !
-#define DVERS    "2.0"
+#define DVERS    "2.2"
 
 // CdCat homepage location:
 #define HOMEPAGE "<a href=\"http://cdcat.sf.net\">http://cdcat.sf.net</a>"
@@ -34,7 +35,7 @@ class QString;
 char  * mstr ( const char *imp );
 QString applicationDirPath ( char **argc );
 QString applicationFilePath ( char **argc );
-
+static QTranslator *translator;
 bool * init_debug_info();
 #endif
 
